@@ -6,7 +6,7 @@ __all__ = [
 
 # This should always be 0.0.0 in master. Only update this after tagging
 # before release.
-__version__ = '10.3.0'
+__version__ = '10.5.0'
 
 import contextlib
 import json
@@ -728,7 +728,7 @@ class DropboxTeam(_DropboxTransport, DropboxTeamBase):
         new_headers = self._headers.copy() if self._headers else {}
         new_headers[select_header_name] = team_member_id
         return Dropbox(
-            self._oauth2_access_token,
+            oauth2_access_token=self._oauth2_access_token,
             oauth2_refresh_token=self._oauth2_refresh_token,
             oauth2_access_token_expiration=self._oauth2_access_token_expiration,
             max_retries_on_error=self._max_retries_on_error,
@@ -737,6 +737,9 @@ class DropboxTeam(_DropboxTransport, DropboxTeamBase):
             user_agent=self._raw_user_agent,
             session=self._session,
             headers=new_headers,
+            app_key=self._app_key,
+            app_secret=self._app_secret,
+            scope=self._scope,
         )
 
 class BadInputException(Exception):
